************
Installation
************

Requirements
============

EclipsingBinaries has the following requirements:

- astropy>=5.1.1
- astroquery>=0.4.6
- ccdproc>=2.4.0
- matplotlib>=3.3.1
- numpy>=1.19.1
- pandas>=1.1.0
- PyAstronomy>=0.18.0
- scipy>=1.5.2
- statsmodels>=0.13.5
- tqdm>=4.64.1
- numba>=0.56.3
- seaborn>=0.12.2
- pyia>=1.3


Installing EclipsingBinaries
============================

To install ccdproc with `pip <https://pip.pypa.io/en/latest/>`_, simply run::

    pip install EclipsingBinaries

Updating
--------

To update to the latest versions, simply run::

    pip install --upgrade EclipsingBinaries

And to install a specified version, simply run::

    pip install --upgrade EclipsingBinaries==[version]
